@@ -10,12 +10,12 @@ use DateTime;
 sub init_widget { 'Compound' }
 
 
-our $VERSION = '0.01';
-
 # This is to keep from reporting missing field
 # for required fields.  Any missing data errors will propogate up.
 sub any_input { 1 }
 
+
+# Create a sub-form that contains the fields that make up this compound field.
 sub init {
     my $self = shift;
 
@@ -55,6 +55,8 @@ sub validate {
     # First validate the sub fields, passing in the original parameters
     return unless $form->validate( scalar $self->form->params );
 
+
+    # This probably should be done in input_to_value()
     my %date = map { $_ => $form->field($_)->value } qw/ day month year hour minute /;
 
     my $dt;
@@ -97,6 +99,55 @@ sub format_value {
 }
 
 
+=head1 NAME
+
+Form::Processor::Field::DateTimeDMYHM2 - DEPRECATED example of a sub-form
+
+=head1 SYNOPSIS
+
+See L<Form::Processor>
+
+=head1 DESCRIPTION
+
+This is a compound field tht is created as a form with multiple fields.
+This is not well tested and should only be used after extensive testing.
+It's more of an example than a real field.
+
+=head2 Widget
+
+Fields can be given a widget type that is used as a hint for
+the code that renders the field.
+
+This field's widget type is: "compound".
+
+=head2 Subclass
+
+Fields may inherit from other fields.  This field
+inherits from: "Field".
+
+=head1 DEPENDENCIES
+
+L<DateTime>
+
+=head1 AUTHORS
+
+Bill Moseley
+
+=head1 COPYRIGHT
+
+See L<Form::Processor> for copyright.
+
+This library is free software, you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
+=head1 SUPPORT / WARRANTY
+
+L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
+Users are expected to review software for fitness and usability.
+
+=cut
+
+
 1;
 
 
