@@ -3,16 +3,14 @@ use strict;
 use warnings;
 use base 'Form::Processor::Field::Text';
 # use Data::Password ();
+#
 
-our $VERSION = '0.01';
 
 sub init_widget { 'password' }
+sub init_min_length { 6 }
+sub init_password { 1 }
+
 
-sub init {
-    my $self = shift;
-    $self->SUPER::init(@_);
-    $self->password(1);
-}
 
 sub validate {
     my $self = shift;
@@ -34,8 +32,6 @@ sub validate {
         if $value =~ /^\d+$/;
 
 
-    return $self->add_error( 'Passwords need to be six or more characters' )
-        if length $value < 6;
 
 
     # This is too strcit.
@@ -62,5 +58,55 @@ sub validate {
 sub required_message { 'Please enter a password in this field' }
 
 
+=head1 NAME
+
+Form::Processor::Field::Password - Input a password
+
+=head1 SYNOPSIS
+
+See L<Form::Processor>
+
+=head1 DESCRIPTION
+
+The password field validates that the does not contain spaces (\s),
+contains only wordcharacters (alphanumeric and underscore \w),
+is not all digets, and is at least 6 characters long.
+
+If there is another field called "login" or "username" will validate
+that it does not match this field (preventing the same text for both login
+and password.
+
+=head2 Widget
+
+Fields can be given a widget type that is used as a hint for
+the code that renders the field.
+
+This field's widget type is: "".
+
+=head2 Subclass
+
+Fields may inherit from other fields.  This field
+inherits from:
+
+=head1 AUTHORS
+
+Bill Moseley
+
+=head1 COPYRIGHT
+
+See L<Form::Processor> for copyright.
+
+This library is free software, you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
+=head1 SUPPORT / WARRANTY
+
+L<Form::Processor> is free software and is provided WITHOUT WARRANTY OF ANY KIND.
+Users are expected to review software for fitness and usability.
+
+=cut
+
+
+
 1;
 
